<?php

declare(strict_types=1);

namespace Drupal\se_invoice\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\RevisionLogInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\se_business\Entity\Business;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Invoice entities.
 *
 * @ingroup se_invoice
 */
interface InvoiceInterface extends ContentEntityInterface, RevisionLogInterface, EntityChangedInterface, EntityOwnerInterface {

  /**
   * Add get/set methods for your configuration properties here.
   */

  /**
   * Gets the Invoice name.
   *
   * @return string
   *   Name of the Invoice.
   */
  public function getName();

  /**
   * Sets the Invoice name.
   *
   * @param string $name
   *   The Invoice name.
   *
   * @return \Drupal\se_invoice\Entity\InvoiceInterface
   *   The called Invoice entity.
   */
  public function setName($name);

  /**
   * Gets the Invoice creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Invoice.
   */
  public function getCreatedTime();

  /**
   * Sets the Invoice creation timestamp.
   *
   * @param int $timestamp
   *   The Invoice creation timestamp.
   *
   * @return \Drupal\se_invoice\Entity\InvoiceInterface
   *   The called Invoice entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Return the search prefix.
   */
  public function getSearchPrefix();

  /**
   * Gets the Invoice revision creation timestamp.
   *
   * @return int
   *   The UNIX timestamp of when this revision was created.
   */
  public function getRevisionCreationTime();

  /**
   * Sets the Invoice revision creation timestamp.
   *
   * @param int $timestamp
   *   The UNIX timestamp of when this revision was created.
   *
   * @return \Drupal\se_invoice\Entity\InvoiceInterface
   *   The called Invoice entity.
   */
  public function setRevisionCreationTime($timestamp);

  /**
   * Gets the Invoice revision author.
   *
   * @return \Drupal\user\UserInterface
   *   The user entity for the revision author.
   */
  public function getRevisionUser();

  /**
   * Sets the Invoice revision author.
   *
   * @param int $uid
   *   The user ID of the revision author.
   *
   * @return \Drupal\se_invoice\Entity\InvoiceInterface
   *   The called Invoice entity.
   */
  public function setRevisionUserId($uid);

  /**
   * Return the total invoice value.
   */
  public function getTotal(): int;

  /**
   * Return the unpaid invoice value.
   */
  public function getOutstanding(): int;

  /**
   * Retrieve the outstanding balance for an invoice.
   */
  public function getInvoiceBalance(): int;

  /**
   * Return the business associated with the invoice.
   */
  public function getBusiness(): Business;

  /**
   * Return a friendly filename for the invoice to be saved as.
   */
  public function generateFilename(): string;
}
